@@ -12,9 +12,7 @@ import pyresdev.utils.data_engineering_functions as DEutils
 
 logger = logging.getLogger(__name__)
 
-__all__ = ['preprocessing_training','preprocessing_predictions']
-
-
+__all__ = ['preprocessing_training', 'preprocessing_predictions']
 
 
 def preprocessing_training_common(df, config, model_type, mapping_dicts=None, imp=None):
@@ -46,10 +44,20 @@ def preprocessing_training_common(df, config, model_type, mapping_dicts=None, im
           .pipe(DEutils.impute_growth)
           .pipe(DEutils.log_transformation, columns=config['cols_to_transform'])
           .pipe(DEutils.correct_C80_success_code)
-          .pipe(DEutils.drop_columns,columns=config['cols_to_drop'])
           )
 
-    #creation and application of the dictionaries
+    if imp:
+        df = DEutils.impute_nas(df=df, columns_to_impute=config['impute_columns'], imp=imp)
+    else:
+        df, imp = DEutils.impute_nas_and_save_imputer(df=df, columns_to_impute=config['impute_columns'])
+        imputer_name = 'imputer_' + config['campaign'] + '.pkl'
+        imputer_output_path = os.path.join('/opt/ml/processing/imputer', imputer_name)
+        logging.info('Saving iterative imputer to {}'.format(imputer_output_path))
+        pickle.dump(imp, open(imputer_output_path, 'wb'))
+
+    df = DEutils.drop_columns(df, columns=config['cols_to_drop'])
+
+    # creation and application of the dictionaries
     if mapping_dicts is None:
         logger.info("No mapping dicts present, creating them")
         mapping_dicts = {}
@@ -76,21 +84,11 @@ def preprocessing_training_common(df, config, model_type, mapping_dicts=None, im
                                                     mapping_dicts['mx_prob'], mapping_dicts['mx_bv'], 'MXType')
 
         df = DEutils.map_conv_prob_using_dictionary(df,
-                                                    mapping_dicts['state_prob'],mapping_dicts['state_bv'],'State')
+                                                    mapping_dicts['state_prob'], mapping_dicts['state_bv'], 'State')
 
         df = DEutils.map_conv_prob_using_dictionary(df,
-                                                    mapping_dicts['industry_prob'],mapping_dicts['industry_bv'], 'Industry')
-
-    # Use imputer
-    impute_columns = config['impute_columns']
-    if imp:
-        df = DEutils.impute_nas(df=df, columns_to_impute=impute_columns, imp=imp)
-    else:
-        df, imp = DEutils.impute_nas_and_save_imputer(df=df, columns_to_impute=impute_columns)
-        imputer_name = 'imputer_' + config['campaign'] + '.pkl'
-        imputer_output_path = os.path.join('/opt/ml/processing/imputer', imputer_name)
-        logging.info('Saving iterative imputer to {}'.format(imputer_output_path))
-        pickle.dump(imp, open(imputer_output_path, 'wb'))
+                                                    mapping_dicts['industry_prob'], mapping_dicts['industry_bv'],
+                                                    'Industry')
 
     return df, imp, mapping_dicts
 
@@ -124,7 +122,7 @@ s
     logging.info(f"{nna}")
 
     # Convert to categories and 
-    df_leads_clean, imp = preprocessing_training_common(df=df_leads_clean,
+    df_leads_clean, imp, mapping_dicts = preprocessing_training_common(df=df_leads_clean,
                                                         config=config,
                                                         mapping_dicts=mapping_dicts,
                                                         model_type=model_type,
@@ -145,8 +143,7 @@ s
     return df_leads_clean, imp
 
 
-def preprocessing_predictions(df,imputer,mapping_dicts,config):
-
+def preprocessing_predictions(df, imputer, mapping_dicts, config):
     df = (df.pipe(DEutils.set_dataframe_columntypes)
           .pipe(DEutils.clean_previous_status, status_to_clean=config['status_to_delete'])
           .pipe(DEutils.clean_rows_with_na, cols_to_clean_na=config['cols_to_clean_na'])
@@ -160,8 +157,8 @@ def preprocessing_predictions(df,imputer,mapping_dicts,config):
           .pipe(DEutils.fill_variables)
           .pipe(DEutils.impute_growth)
           .pipe(DEutils.log_transformation, columns=config['cols_to_transform'])
-          .pipe(DEutils.drop_columns,columns=config['cols_to_drop'][model_type])
+          .pipe(DEutils.drop_columns, columns=config['cols_to_drop'][model_type])
           .pipe(DEutils.correct_C80_success_code)
           )
 
-    return df
\ No newline at end of file
+    return df
